@@ -1,5 +1,5 @@
 /*
- * BluezQt - Asynchronous Bluez wrapper library
+ * BluezQt - Asynchronous BlueZ wrapper library
  *
  * Copyright (C) 2014-2015 David Rosca <nowrep@gmail.com>
  *
@@ -26,7 +26,7 @@
 #include <QAbstractListModel>
 
 #include "types.h"
-#include <bluezqt_export.h>
+#include "bluezqt_export.h"
 
 namespace BluezQt
 {
@@ -43,12 +43,11 @@ class Device;
  * @code
  * import org.kde.bluezqt 1.0 as BluezQt
  *
- * BluezQt.Manager {
- *     id: btManager;
- * }
- *
- * BluezQt.DevicesModel {
- *     manager: btManager
+ * ListView {
+ *     model: BluezQt.DevicesModel { }
+ *     delegate: Text {
+ *         text: "%1 (%2)".arg(Name).arg(Address)
+ *     }
  * }
  * @endcode
  */
@@ -72,9 +71,9 @@ public:
         /** Remote name of the device (QString) */
         RemoteNameRole = Qt::UserRole + 104,
         /** Class of the device (quint32) */
-        DeviceClassRole = Qt::UserRole + 105,
+        ClassRole = Qt::UserRole + 105,
         /** Type of the device (DeviceType) */
-        DeviceTypeRole = Qt::UserRole + 106,
+        TypeRole = Qt::UserRole + 106,
         /** Appearance of the device (quint16) */
         AppearanceRole = Qt::UserRole + 107,
         /** Icon name of the device (QString) */
